==> hyades.source_3.0.0_20040621_1225.zip: org/eclipse/hyades/test/ui/launch/delegates/BasicTestComponentLaunchConfigurationDelegate.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.launch.delegates;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.model.ILaunchConfigurationDelegate;
import org.eclipse.hyades.models.common.testprofile.TPFDeployment;
import org.eclipse.hyades.models.common.testprofile.TPFTestComponent;
import org.eclipse.hyades.test.ui.launch.configurations.DeploymentLaunchConfigurationFacade;
import org.eclipse.hyades.test.ui.launch.configurations.ExecutionHistoryLaunchConfigurationFacade;
import org.eclipse.hyades.test.ui.launch.configurations.TestComponentLaunchConfigurationFacade;

/**
 * This class is the Delegate for the basic Hyades Launch Configuration.
 * It handles the launching of a Hyades Test Component according to a Hyades Launch Configuration.
 * In Atlantic, this Launch Configuration delegate is abstract: the invokeTestExecutionHarness()
 * method must be implemented in sub-classes. In future versions, a Basic Test Component
 * Launch Configuration will be available and this class will be instantiable.
 * @see ILaunchConfigurationDelegate
 * @author jcanches
 */
public abstract class BasicTestComponentLaunchConfigurationDelegate extends AbstractLaunchConfigurationDelegate {
	
    /**
     * Create a Hyades Basic Launch Configuration Delegate.
     */
    public BasicTestComponentLaunchConfigurationDelegate() {
    }

    protected TPFTestComponent getLaunchedTestComponent(ILaunchConfiguration configuration) throws CoreException {
    	return TestComponentLaunchConfigurationFacade.getTestComponent(configuration);
    }
    
    protected TPFDeployment getDeployment(ILaunchConfiguration configuration) throws CoreException {
    	return DeploymentLaunchConfigurationFacade.getDeployment(configuration);
    }
    
    protected String getTestExecutionHistoryName(ILaunchConfiguration configuration) throws CoreException {
    	return ExecutionHistoryLaunchConfigurationFacade.getExecutionHistoryName(configuration);
    }
    
    protected IContainer getTestExecutionHistoryLocation(ILaunchConfiguration configuration) throws CoreException {
    	return ExecutionHistoryLaunchConfigurationFacade.getExecutionHistoryLocation(configuration);
    }   
    
	protected Object getLaunchedElement(ILaunchConfiguration configuration)	throws CoreException {
		return getLaunchedTestComponent(configuration);
	}
	
    protected void validate(ILaunchConfiguration configuration, String mode) throws CoreException {
    	super.validate(configuration, mode);
   	
    	if (getDeployment(configuration) == null) {
			reportProblem("The configuration does not provide a Deployment"); //$NON-NLS-1$
		}
    	
    	String tehName = getTestExecutionHistoryName(configuration);
    	if (tehName == null || tehName.equals("")) { //$NON-NLS-1$
    		reportProblem("The configuration does not provide a Test Execution History Name"); //$NON-NLS-1$
    	}
    	
    	IContainer tehLocation = getTestExecutionHistoryLocation(configuration);
    	if (tehLocation == null) {
    		reportProblem("The configuration does not provide a Test Execution History Location"); //$NON-NLS-1$
    	} else if (!tehLocation.exists()) {
    		reportProblem("The Test Execution History Location described by the configuration does not exist"); //$NON-NLS-1$
    	}
    }
        
}

==> hyades.source_3.2.0_20041221_1637.zip: org/eclipse/hyades/test/ui/launch/delegates/BasicTestComponentLaunchConfigurationDelegate.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.launch.delegates;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.model.ILaunchConfigurationDelegate;
import org.eclipse.hyades.models.common.testprofile.TPFDeployment;
import org.eclipse.hyades.models.common.testprofile.TPFTestComponent;
import org.eclipse.hyades.test.ui.launch.configurations.DeploymentLaunchConfigurationFacade;
import org.eclipse.hyades.test.ui.launch.configurations.ExecutionHistoryLaunchConfigurationFacade;
import org.eclipse.hyades.test.ui.launch.configurations.TestComponentLaunchConfigurationFacade;

/**
 * This class is the Delegate for the basic Hyades Launch Configuration.
 * It handles the launching of a Hyades Test Component according to a Hyades Launch Configuration.
 * In Atlantic, this Launch Configuration delegate is abstract: the invokeTestExecutionHarness()
 * method must be implemented in sub-classes. In future versions, a Basic Test Component
 * Launch Configuration will be available and this class will be instantiable.
 * @see ILaunchConfigurationDelegate
 * @author jcanches
 * @deprecated Use BasicTestComponentLaunchConfigurationDelegate2 instead.
 */
public abstract class BasicTestComponentLaunchConfigurationDelegate extends AbstractLaunchConfigurationDelegate {
	
    /**
     * Create a Hyades Basic Launch Configuration Delegate.
     */
    public BasicTestComponentLaunchConfigurationDelegate() {
    }

    protected TPFTestComponent getLaunchedTestComponent(ILaunchConfiguration configuration) throws CoreException {
    	return TestComponentLaunchConfigurationFacade.getTestComponent(configuration, getResourceSet());
    }
    
    protected TPFDeployment getDeployment(ILaunchConfiguration configuration) throws CoreException {
    	return DeploymentLaunchConfigurationFacade.getDeployment(configuration, getResourceSet());
    }
    
    protected String getTestExecutionHistoryName(ILaunchConfiguration configuration) throws CoreException {
    	return ExecutionHistoryLaunchConfigurationFacade.getExecutionHistoryName(configuration);
    }
    
    protected IContainer getTestExecutionHistoryLocation(ILaunchConfiguration configuration) throws CoreException {
    	return ExecutionHistoryLaunchConfigurationFacade.getExecutionHistoryLocation(configuration);
    }   
    
	protected Object getLaunchedElement(ILaunchConfiguration configuration)	throws CoreException {
		return getLaunchedTestComponent(configuration);
	}
	
    protected void validate(ILaunchConfiguration configuration, String mode) throws CoreException {
    	super.validate(configuration, mode);
   	
    	if (getDeployment(configuration) == null) {
			reportProblem("The configuration does not provide a Deployment"); //$NON-NLS-1$
		}
    	
    	String tehName = getTestExecutionHistoryName(configuration);
    	if (tehName == null || tehName.equals("")) { //$NON-NLS-1$
    		reportProblem("The configuration does not provide a Test Execution History Name"); //$NON-NLS-1$
    	}
    	
    	IContainer tehLocation = getTestExecutionHistoryLocation(configuration);
    	if (tehLocation == null) {
    		reportProblem("The configuration does not provide a Test Execution History Location"); //$NON-NLS-1$
    	} else if (!tehLocation.exists()) {
    		reportProblem("The Test Execution History Location described by the configuration does not exist"); //$NON-NLS-1$
    	}
    }
        
}
